# Harness-Bench Comparison Report

**Date:** 2026-02-22T14:41:51
**Tasks:** 8

## Overall Results

| Agent | gpt52 |
|-------|------|
| **harness** | 8/8 (100%) |

## Per-Task Results

### Model: gpt52

| Task | harness |
|------|------|
| hb-multi-file-01 | PASS (13.2s) |
| hb-recovery-01 | PASS (5.2s) |
| hb-tool-efficiency-01 | PASS (3.1s) |
| hb-context-01 | PASS (12.6s) |
| hb-create-01 | PASS (3.5s) |
| hb-bugfix-01 | PASS (5.6s) |
| hb-analyze-01 | PASS (1.8s) |
| hb-refactor-01 | PASS (7.2s) |

## Timing

| Agent | Model | Avg Duration | Total Duration |
|-------|-------|-------------|----------------|
| harness | gpt52 | 6.5s | 52.2s |
